# libquantum

### Description
Standardized time-frequency representations 
built on Gabor uncertainty principle for 
logarithmic constant Q base 2 (binary) frequency bands 
of quantized order N.

NOTE: 
Requirements upgraded to run on Apple M1 Silicon chip 
with the RedVox SDK version 3.1.0 or later. Please read the notes on requirements.txt

Refer to the open access publications:

- [Garces (2020), Quantized Constant-Q Gabor Atoms for 
Sparse Binary Representations of Cyber-Physical Signatures](https://www.mdpi.com/1099-4300/22/9/936)

- [Garces (2013), On Infrasound Standards, Part 1 Time, Frequency, and Energy Scaling](https://m.scirp.org/papers/abstract/33802)


For the GT blast pulse, refer to:

- [Garcés, M. A. (2019). Explosion Source Models,
Chapter in Infrasound Monitoring for Atmospheric Studies,
Second Edition, Springer](https://www.springer.com/gp/book/9783319751382)

- [Schnurr, J. M., K. Kim, M. A. Garcés, A. Rodgers (2020). 
Improved parametric models for explosion pressure signals 
derived from large datasets, 
Seism. Res. Lett.](https://pubs.geoscienceworld.org/ssa/srl/article-abstract/91/3/1752/582897/Improved-Parametric-Models-for-Explosion-Pressure?redirectedFrom=fulltext)

- [Kim, K, A. R. Rodgers, M. A. Garces, and S. C. Myers (2021).
Empirical Acoustic Source Model for Chemical Explosions in Air,
Bulletin of the Seismological Society of America](https://pubs.geoscienceworld.org/ssa/bssa/article-abstract/doi/10.1785/0120210030/600721/Empirical-Acoustic-Source-Model-for-Chemical?redirectedFrom=fulltext)

Recommended reading in chronological order:
- Gabor, D. Theory of Communication, Part 3. Electr. Eng. 1946, 93, 445–457.
- Shannon, C.E. The Mathematical Theory of Communication; University of Illinois Press: Urbana, IL, USA, 1998; [1949 first ed].
- Harris, F. J. On the Use of Windows for Harmonic Analysis with the Discrete Fourier Transform, Proceedings of the IEEE, 1978, 66 (1), 51-83.
- Cohen, L. Time-Frequency Analysis, Prentice-Hall, NI 07458, 1995.
- Stockwell, R. G., Mansina, L, and R. P. Lowe. Localization of the Complex Spectrum: The S Transform. Signal Processing, IEEE Transactions, 1996, 44 no. 4, 998-1001.
- Mallat, S. A Wavelet Tour of Signal Processing: The Sparse Way, 3rd ed.; Academic Press: Cambridge, MA, USA, 2009 [1998 first ed].



### Installation

```shell script
pip install libquantum
```
More details in the [Installation guide](https://github.com/RedVoxInc/libquantum/blob/master/docs/libquantum/intallation.md#libquantum-installation).

### Examples
Full examples can be found in the [examples documentation](https://github.com/RedVoxInc/libquantum/blob/master/docs/libquantum/examples.md#examples-using-libquantum).

### API Documentation
Check the [API Documentation](https://redvoxinc.github.io/libquantum).

### Resources

- Found an issue? Submit a [bug report](https://github.com/RedVoxInc/libquantum/issues).
- [Apache License](https://github.com/RedVoxInc/libquantum/blob/master/LICENSE)
